@@ -49,6 +49,8 @@ extern void _s_open(STREAM * s,int mode);
 
 S_TABLE s_terminal_table = {
     'e',
+	STF_BUF_OUT,
+	{0,0},
     0,
     s_error_stream,
     s_close_terminal,
