@@ -53,39 +53,6 @@ unlock_db(PMD_WORK * w)
 }
 
 
-void
-floating_endian(FLOATING_INDEX * ix,int len)
-{
-	change_endian_i(ix->fofs);
-	change_endian_f(ix->d);
-}
-
-void
-gb_time_endian(GB_TIME_INDEX * ix,int len)
-{
-	change_endian_i(ix->fofs);
-	change_endian_gb_time(&ix->d);
-}
-
-
-void
-string_endian(STRING_INDEX * ix,int len)
-{
-int i;
-	change_endian_i(ix->fofs);
-	len = (len - sizeof(ix->fofs))/sizeof(L_CHAR);
-	for ( i = 0 ; i < len ; i ++ ) {
-		change_endian_i(ix->d[i]);
-	}
-}
-
-void
-timeout_endian(TIMEOUT_INDEX * ix,int len)
-{
-	change_endian_i(ix->fofs);
-	change_endian_i(ix->timeout);
-}
-
 
 void
 change_endian_pmd_header(PN_PMD_HEADER * h)
@@ -153,25 +120,6 @@ int n,i;
 	}
 }
 
-int
-cmp_target(STRING_INDEX * ix1,STRING_INDEX * ix2)
-{
-L_CHAR * c1,* c2;
-L_CHAR * o1,* o2;
-int len,ret;
-
-	c1 = ix1->d;
-	c2 = ix2->d;
-	ret = l_strcmp(c1,c2);
-	if ( ret )
-		return ret;
-	len = l_strlen(c1);
-	o1 = &ix1->d[len+1];
-	len = l_strlen(c2);
-	o2 = &ix2->d[len+1];
-	return l_strcmp(o1,o2);
-}
-
 int
 cmp_floating(FLOATING_INDEX * f1,FLOATING_INDEX * f2)
 {
@@ -214,55 +162,55 @@ int ret;
 	h->h.fofs = alloc_filespace(p,&h->d.h);
 	strcpy(h->d.version,PMD_VERSION);
 	h->d.flags = 0;
-	rt = favt_alloc_root(p,FAT_PMD_FLOATING,floating_endian);
+	rt = favt_alloc_root(p,FAT_PMD_FLOATING,favt_floating_endian);
 	if ( rt == 0 ) {
 		ret = 0;
 		goto end;
 	}
 	h->d.ix_tl_x = rt->h.fofs;
-	rt = favt_alloc_root(p,FAT_PMD_FLOATING,floating_endian);
+	rt = favt_alloc_root(p,FAT_PMD_FLOATING,favt_floating_endian);
 	if ( rt == 0 ) {
 		ret = 0;
 		goto end;
 	}
 	h->d.ix_tl_y = rt->h.fofs;
-	rt = favt_alloc_root(p,FAT_PMD_FLOATING,floating_endian);
+	rt = favt_alloc_root(p,FAT_PMD_FLOATING,favt_floating_endian);
 	if ( rt == 0 ) {
 		ret = 0;
 		goto end;
 	}
 	h->d.ix_br_x = rt->h.fofs;
-	rt = favt_alloc_root(p,FAT_PMD_FLOATING,floating_endian);
+	rt = favt_alloc_root(p,FAT_PMD_FLOATING,favt_floating_endian);
 	if ( rt == 0 ) {
 		ret = 0;
 		goto end;
 	}
 	h->d.ix_br_y = rt->h.fofs;
-	rt = favt_alloc_root(p,FAT_PMD_FLOATING,floating_endian);
+	rt = favt_alloc_root(p,FAT_PMD_FLOATING,favt_floating_endian);
 	if ( rt == 0 ) {
 		ret = 0;
 		goto end;
 	}
 	h->d.ix_resolution = rt->h.fofs;
-	rt = favt_alloc_root(p,FAT_PMD_GB_TIME,gb_time_endian);
+	rt = favt_alloc_root(p,FAT_PMD_GB_TIME,favt_gb_time_endian);
 	if ( rt == 0 ) {
 		ret = 0;
 		goto end;
 	}
 	h->d.ix_content_period_from = rt->h.fofs;
-	rt = favt_alloc_root(p,FAT_PMD_GB_TIME,gb_time_endian);
+	rt = favt_alloc_root(p,FAT_PMD_GB_TIME,favt_gb_time_endian);
 	if ( rt == 0 ) {
 		ret = 0;
 		goto end;
 	}
 	h->d.ix_content_period_to = rt->h.fofs;
-	rt = favt_alloc_root(p,FAT_PMD_STRING,string_endian);
+	rt = favt_alloc_root(p,FAT_PMD_STRING,favt_string_endian);
 	if ( rt == 0 ) {
 		ret = 0;
 		goto end;
 	}
 	h->d.ix_target = rt->h.fofs;
-	rt = favt_alloc_root(p,FAT_PMD_TIMEOUT,timeout_endian);
+	rt = favt_alloc_root(p,FAT_PMD_TIMEOUT,favt_timeout_endian);
 	if ( rt == 0 ) {
 		ret = 0;
 		goto end;
@@ -714,7 +662,7 @@ int crd_len,obj_len;
 FAVT_NODE * n;
 FAVT_ROOT * r;
 
-	r = get_root(w->p,w->pmd_h.d.ix_target,string_endian);
+	r = get_root(w->p,w->pmd_h.d.ix_target,favt_string_endian);
 	if ( r == 0 ) {
 		w->err = -1;
 		return 0;
@@ -726,7 +674,7 @@ FAVT_ROOT * r;
 	ix->fofs = 0;
 	l_strcpy(ix->d,crd);
 	l_strcpy(&ix->d[crd_len+1],obj);
-	n = favt_search(r,root_node(r),ix,cmp_target);
+	n = favt_search(r,root_node(r),ix,favt_cmp_string_2);
 	d_f_ree(ix);
 	if ( n == 0 )
 		return 0;
@@ -742,7 +690,7 @@ STRING_INDEX * ix;
 int crd_len,obj_len;
 FAVT_NODE * n, *nn;
 FAVT_ROOT * r;
-	r = get_root(w->p,w->pmd_h.d.ix_target,string_endian);
+	r = get_root(w->p,w->pmd_h.d.ix_target,favt_string_endian);
 	if ( r == 0 ) {
 		w->err = -1;
 		return -1;
@@ -760,7 +708,7 @@ FAVT_ROOT * r;
 		d_f_ree(ix);
 		return -1;
 	}
-	nn = favt_insert(r,&r->node,n,cmp_target);
+	nn = favt_insert(r,&r->node,n,favt_cmp_string_2);
 	if ( nn != n ) {
 		w->err = -1;
 		d_f_ree(ix);
@@ -777,7 +725,7 @@ STRING_INDEX * ix;
 int crd_len,obj_len;
 FAVT_NODE * n;
 FAVT_ROOT * r;
-	r = get_root(w->p,w->pmd_h.d.ix_target,string_endian);
+	r = get_root(w->p,w->pmd_h.d.ix_target,favt_string_endian);
 	if ( r == 0 ) {
 		w->err = -1;
 		return -1;
@@ -789,7 +737,7 @@ FAVT_ROOT * r;
 	ix->fofs = 0;
 	l_strcpy(ix->d,crd);
 	l_strcpy(&ix->d[crd_len+1],obj);
-	n = favt_delete(r,&r->node,ix,cmp_target);
+	n = favt_delete(r,&r->node,ix,favt_cmp_string_2);
 	favt_free_node(n);
 	d_f_ree(ix);
 	return 0;
@@ -1010,7 +958,7 @@ int er;
 		&t->minrect.tl.x,
 		sizeof(t->minrect.tl.x),
 		t->fofs,
-		floating_endian,
+		favt_floating_endian,
 		cmp_floating);
 	if ( er < 0 )
 		return -1;
@@ -1019,7 +967,7 @@ int er;
 		&t->minrect.tl.y,
 		sizeof(t->minrect.tl.y),
 		t->fofs,
-		floating_endian,
+		favt_floating_endian,
 		cmp_floating);
 	if ( er < 0 )
 		return -1;
@@ -1028,7 +976,7 @@ int er;
 		&t->minrect.br.x,
 		sizeof(t->minrect.br.x),
 		t->fofs,
-		floating_endian,
+		favt_floating_endian,
 		cmp_floating);
 	if ( er < 0 )
 		return -1;
@@ -1037,7 +985,7 @@ int er;
 		&t->minrect.br.y,
 		sizeof(t->minrect.br.y),
 		t->fofs,
-		floating_endian,
+		favt_floating_endian,
 		cmp_floating);
 	if ( er < 0 )
 		return -1;
@@ -1046,7 +994,7 @@ int er;
 		&t->resolution,
 		sizeof(t->resolution),
 		t->fofs,
-		floating_endian,
+		favt_floating_endian,
 		cmp_floating);
 	if ( er < 0 )
 		return -1;
@@ -1055,7 +1003,7 @@ int er;
 		&t->content_period_from,
 		sizeof(t->content_period_from),
 		t->fofs,
-		gb_time_endian,
+		favt_gb_time_endian,
 		cmp_gb_time);
 	if ( er < 0 )
 		return -1;
@@ -1064,7 +1012,7 @@ int er;
 		&t->content_period_to,
 		sizeof(t->content_period_to),
 		t->fofs,
-		gb_time_endian,
+		favt_gb_time_endian,
 		cmp_gb_time);
 	if ( er < 0 )
 		return -1;
@@ -1073,7 +1021,7 @@ int er;
 		&t->timeout,
 		sizeof(t->timeout),
 		t->fofs,
-		timeout_endian,
+		favt_timeout_endian,
 		cmp_timeout);
 	if ( er < 0 )
 		return -1;
@@ -1097,7 +1045,7 @@ int er;
 		&t->minrect.tl.x,
 		sizeof(t->minrect.tl.x),
 		t->fofs,
-		floating_endian,
+		favt_floating_endian,
 		cmp_floating);
 	if ( er < 0 )
 		return -1;
@@ -1106,7 +1054,7 @@ int er;
 		&t->minrect.tl.y,
 		sizeof(t->minrect.tl.y),
 		t->fofs,
-		floating_endian,
+		favt_floating_endian,
 		cmp_floating);
 	if ( er < 0 )
 		return -1;
@@ -1115,7 +1063,7 @@ int er;
 		&t->minrect.br.x,
 		sizeof(t->minrect.br.x),
 		t->fofs,
-		floating_endian,
+		favt_floating_endian,
 		cmp_floating);
 	if ( er < 0 )
 		return -1;
@@ -1124,7 +1072,7 @@ int er;
 		&t->minrect.br.y,
 		sizeof(t->minrect.br.y),
 		t->fofs,
-		floating_endian,
+		favt_floating_endian,
 		cmp_floating);
 	if ( er < 0 )
 		return -1;
@@ -1133,7 +1081,7 @@ int er;
 		&t->resolution,
 		sizeof(t->resolution),
 		t->fofs,
-		floating_endian,
+		favt_floating_endian,
 		cmp_floating);
 	if ( er < 0 )
 		return -1;
@@ -1142,7 +1090,7 @@ int er;
 		&t->content_period_from,
 		sizeof(t->content_period_from),
 		t->fofs,
-		gb_time_endian,
+		favt_gb_time_endian,
 		cmp_gb_time);
 	if ( er < 0 )
 		return -1;
@@ -1151,7 +1099,7 @@ int er;
 		&t->content_period_to,
 		sizeof(t->content_period_to),
 		t->fofs,
-		gb_time_endian,
+		favt_gb_time_endian,
 		cmp_gb_time);
 	if ( er < 0 )
 		return -1;
@@ -1160,7 +1108,7 @@ int er;
 		&t->timeout,
 		sizeof(t->timeout),
 		t->fofs,
-		timeout_endian,
+		favt_timeout_endian,
 		cmp_timeout);
 	if ( er < 0 )
 		return -1;
@@ -1181,7 +1129,7 @@ int er;
 		&t->timeout,
 		sizeof(t->timeout),
 		t->fofs,
-		timeout_endian,
+		favt_timeout_endian,
 		cmp_timeout);
 	if ( er < 0 )
 		return -1;
@@ -1190,7 +1138,7 @@ int er;
 		&t->timeout,
 		sizeof(t->timeout),
 		t->fofs,
-		timeout_endian,
+		favt_timeout_endian,
 		cmp_timeout);
 	if ( er < 0 )
 		return er;
@@ -1207,7 +1155,7 @@ int d_len;
 		&d_len,
 		w,
 		root,
-		floating_endian,
+		favt_floating_endian,
 		favt_trace_from_small);
 	if ( f == 0 )
 		return -1;
@@ -1217,7 +1165,7 @@ int d_len;
 		&d_len,
 		w,
 		root,
-		floating_endian,
+		favt_floating_endian,
 		favt_trace_from_large);
 	if ( f == 0 )
 		return -1;
@@ -1237,7 +1185,7 @@ int d_len;
 		&d_len,
 		w,
 		root_from,
-		gb_time_endian,
+		favt_gb_time_endian,
 		favt_trace_from_small);
 	if ( f == 0 )
 		return -1;
@@ -1247,7 +1195,7 @@ int d_len;
 		&d_len,
 		w,
 		root_to,
-		gb_time_endian,
+		favt_gb_time_endian,
 		favt_trace_from_large);
 	if ( f == 0 )
 		return -1;
@@ -1322,7 +1270,7 @@ ACC_PN_PMD_OFSLIST * ol;
 int len;
 int i;
 PMD_TEMP_LIST * ret;
-	r = get_root(w->p,w->pmd_h.d.ix_resolution,floating_endian);
+	r = get_root(w->p,w->pmd_h.d.ix_resolution,favt_floating_endian);
 	if ( r == 0 )
 		return 0;
 	ix_min.d = reso_min;
@@ -1371,7 +1319,7 @@ ACC_PN_PMD_OFSLIST * ol;
 int len;
 int i;
 PMD_TEMP_LIST * ret, * tl;
-	r = get_root(w->p,w->pmd_h.d.ix_timeout,timeout_endian);
+	r = get_root(w->p,w->pmd_h.d.ix_timeout,favt_timeout_endian);
 	if ( r == 0 )
 		return;
 	ix_min.timeout = 0;
