@@ -1256,7 +1256,7 @@ int ret;
 	d = _search_rs_cache_entry(url);
 	if ( d == 0 )
 		return -1;
-	ret = 0;
+	ret = -1;
 	if ( _delete_rs_timer(d->d.expire,d->h.fofs) < 0 )
 		goto end;
 	d->d.expire = expire;
@@ -1385,15 +1385,26 @@ CHAIN_LIST * c;
 	return 0;
 }
 
+void
+all_load(XL_SEXP * s)
+{
+	for ( ; get_type(s) == XLT_PAIR ; s = cdr(s) );
+}
+
+
 XL_SEXP *
 get_xl_sexp_from_string(L_CHAR * str)
 {
 STREAM * s;
+XL_SEXP * ret, * load;
 
 	s = s_open_string_read(str,&int_cm,
 		(l_strlen(str)+1)*sizeof(L_CHAR),
 		1);
-	return car(init_parse(s,l_string(std_cm,"get_xl_sexp_from_string"),0));
+	ret = car(load = 
+		init_parse(s,l_string(std_cm,"get_xl_sexp_from_string"),0));
+	all_load(load);
+	return ret;
 }
 
 int
@@ -1623,7 +1634,6 @@ CHAIN_LIST * c;
 	ret->c.weight = cr->weight;
 	INIT_RING(&ret->c.map_children);
 	INIT_RING(&ret->c.map_parents);
-
 	if ( c == 0 )
 		goto err;
 	ret->c.mode = string_to_host(c->ptr);
@@ -1674,7 +1684,6 @@ CHAIN_LIST * c;
 		if ( set_rs_clip(&ret->c.clip,lst) < 0 )
 			goto err;
 	}
-
 	return ret;
 err:
 	free_resource_entry(ret);
@@ -2153,6 +2162,10 @@ RECORD_LIST * lst, ** p, * tar;
 PN_RS_COORDINATE * c;
 CLIP * cp;
 MAP * mp;
+int flags;
+	if ( r->c.cid == 0 )
+		return 0;
+	flags = r->h.flags;
 	lst = 0;
 	p = &lst;
 	p = _set_rs_res_status(p);
@@ -2172,10 +2185,12 @@ MAP * mp;
 	_save_string_to_cache(tar,r->c.body_pri,0);
 	_save_string_to_cache(tar,r->c.relation_master,0);
 	_save_string_to_cache(tar,r->c.relation_slave,0);
-	for ( mp = R_NEXT(MAP*,&r->c.map_children);
-			mp != (MAP*)&r->c.map_children;
-			mp = R_NEXT(MAP*,&mp->h) )
-		p = _save_rs_map(mp,p);
+	if ( flags & RF_LOAD_EXTEND ) {
+		for ( mp = R_NEXT(MAP*,&r->c.map_children);
+				mp != (MAP*)&r->c.map_children;
+				mp = R_NEXT(MAP*,&mp->h) )
+			p = _save_rs_map(mp,p);
+	}
 	p = _save_rs_null(p);
 	for ( cp = r->c.clip ; cp ; cp = cp->next )
 		p = _save_rs_clip(cp,p);
@@ -2388,7 +2403,7 @@ int
 _get_rs_str(XL_SEXP ** retp,L_CHAR * filepath)
 {
 STREAM * st;
-XL_SEXP * ret, * p;
+XL_SEXP * ret, * p, * load;
 int _ret;
 void gc_gb_sexp();
 	st = s_open_file(n_string(std_cm,filepath),O_RDONLY);
@@ -2396,7 +2411,8 @@ void gc_gb_sexp();
 		return -1;
 	s_set_cm(st,&int_cm);
 	gc_push(0,0,"_get_rs_str");
-	*retp = ret = car(init_parse(st,filepath,filepath));
+	*retp = ret = car(load = init_parse(st,filepath,filepath));
+	all_load(load);
 	for ( p = ret ; ; p = cdr(p) ) {
 		switch ( get_type(p) ) {
 		case XLT_PAIR:
@@ -2411,7 +2427,6 @@ void gc_gb_sexp();
 		break;
 	}
 	gc_pop(ret,gc_gb_sexp);
-	s_close(st);
 	return _ret;
 }
 
@@ -2467,7 +2482,7 @@ retry:
 			goto idle2;
 		goto retry;
 	}
-	rlock_rcache(&resource_cache);
+	wlock_rcache(&resource_cache);
 	if ( rs_p == 0 ) {
 		_open_rs_cache();
 		if ( resource_cache.err < 0 )
@@ -2538,7 +2553,7 @@ char * _f;
 int del;
 int rr;
 
-	b->flags = 0;
+	memset(b,0,sizeof(*b));
 retry:
 	del = 0;
 	rr = -1;
