@@ -809,13 +809,13 @@ int * _cid;
 int i;
 L_CHAR * b;
 	if ( get_type(cid) != XLT_PAIR )
-		return -1;
+		goto err;
 	sym = car(cid);
 	if ( get_type(sym) != XLT_SYMBOL )
-		return -1;
+		goto err;
 	len = list_length(cid);
 	if ( len < 0 )
-		return -1;
+		goto err;
 	c->cid = _cid = d_alloc(sizeof(int)*len,2436);
 	cid = cdr(cid);
 	_cid[0] = len;
@@ -835,7 +835,8 @@ L_CHAR * b;
 		c->body_pri = ll_copy_str(b,1356);
 	return 0;
 err:
-	d_f_ree(c->cid);
+	if ( c->cid )
+		d_f_ree(c->cid);
 	c->cid = 0;
 	return -1;
 }
