@@ -27,6 +27,7 @@
 #include	"lock_level.h"
 #include	"pri_level.h"
 #include	"rs_cache.h"
+#include	"save_global.h"
 #define HANDLING_MAX		20
 
 
@@ -63,6 +64,21 @@ void gc_lrw();
 void gc_lrw_get();
 void gc_gb_sexp();
 
+void
+resource_global()
+{
+	SG_TITLE;
+
+	sg("SEM",	"res_lock",	&res_lock);
+	sg("SYS_QUEUE",	"res_q0",	&res_q0);
+	sg("SYS_QUEUE",	"res_q1",	&res_q1);
+	sg("SYS_QUEUE",	"res_q2",	&res_q2);
+	sg("SYS_QUEUE",	"res_lp1",	&res_lp1);
+	sg("SYS_QUEUE",	"res_disposer",	&res_disposer);
+	sg("SYS_QUEUE",	"res_extend",	&res_extend);
+	sg("LOAD_RESOURCE_WORK","first_list",&first_list);
+}
+
 void
 init_load_resource()
 {
@@ -124,6 +140,8 @@ init_load_resource()
 	setup_queue(&res_disposer);
 
 	create_task(resource_disposer_task,0,PRI_FETCH);
+
+	resource_global();
 }
 
 
@@ -314,6 +332,18 @@ LOAD_RESOURCE_WORK * wp;
 	return 0;
 }
 
+LOAD_RESOURCE_WORK *
+_search_first_list_by_url(L_CHAR * url,int opt)
+{
+LOAD_RESOURCE_WORK * wp;
+	for ( wp = first_list ; wp ; wp = wp->first_next )
+		if ( l_strcmp(url,
+				get_url_str2(&wp->url)) == 0 &&
+				opt == wp->option )
+			return wp;
+	return 0;
+}
+
 void
 _delete_first_list(LOAD_RESOURCE_WORK * w)
 {
@@ -358,7 +388,7 @@ release_first_list(LOAD_RESOURCE_WORK * w)
 }
 
 void
-_res_end_op_extend(LOAD_RESOURCE_WORK * w,int err,RESOURCE * r)
+_res_end_op_extend(LOAD_RESOURCE_WORK * w,int err,RESOURCE * r,int clear)
 {
 LOAD_RESOURCE_WORK * wp;
 L_CHAR * f, * g;
@@ -374,7 +404,7 @@ L_CHAR * f, * g;
 	}
 	if ( r ) {
 		r->h.flags |= RF_LOAD_EXTEND;
-		r->h.flags &= ~RF_LOAD_EXTEND_PROC;
+		r->h.flags &= ~(RF_LOAD_EXTEND_PROC|clear);
 		wakeup_task((int)r);
 		rcache_invoke();
 	}
@@ -382,13 +412,13 @@ L_CHAR * f, * g;
 }
 
 void
-res_end_op_extend(LOAD_RESOURCE_WORK * w,int err,RESOURCE * r)
+res_end_op_extend(LOAD_RESOURCE_WORK * w,int err,RESOURCE * r,int clear)
 {
 int (* func)();
 
 	lock_task(res_lock);
 	func = w->wup_func;
-	_res_end_op_extend(w,err,r);
+	_res_end_op_extend(w,err,r,clear);
 	unlock_task(res_lock,"res_end_op_extend");
 	if ( func )
 		(*func)();
@@ -668,7 +698,7 @@ print_sexp(s_stdout,ret,0);
 ss_printf("\n");
 			if ( extend_flag )
 				res_end_op_extend(w,LRWE_ERROR_GET1,
-					w->result);
+					w->result,0);
 			else	res_end_op(w,LRWE_ERROR_GET1,0);
 		}
 		else {
@@ -974,7 +1004,12 @@ RESOURCE_TYPE_LIST * rt;
 		if ( !(wp1->result->h.flags & RF_COMPLETE) )
 			er_panic("_lr_extend_insert");
 		if ( wp1->result->h.flags & 
-				(RF_LOAD_EXTEND|RF_LOAD_EXTEND_PROC) ){
+				RF_LOAD_EXTEND_PROC ){
+			goto free_next_in_lock;
+		}
+		if ( wp1->result->h.flags &
+				RF_LOAD_EXTEND ) {
+			_res_end_op_extend(wp1,LRWE_OK,wp1->result,0);
 			goto free_next_in_lock;
 		}
 		_resource_fix_wait(wp1->result);
@@ -991,7 +1026,7 @@ RESOURCE_TYPE_LIST * rt;
 			lp = wp1;
 		}
 		else {
-			res_end_op_extend(wp1,LRWE_OK,wp1->result);
+			res_end_op_extend(wp1,LRWE_OK,wp1->result,0);
 			goto free_next;
 		}
 		continue;
@@ -1349,7 +1384,7 @@ int ret_f;
 		for ( ; lp  ; lp = lp->que_next ) {
 			if ( lp->rt->setup_function )
 				(*lp->rt->setup_function)(lp);
-			res_end_op_extend(lp,LRWE_OK,lp->result);
+			res_end_op_extend(lp,LRWE_OK,lp->result,RF_CACHE);
 		}
 		free_lrw_que_next(w);
 		gc_pop(0,0);
@@ -1687,17 +1722,23 @@ URL u;
 	r = search_resource_by_entry(&u);
 	free_url(&u);
 	if ( r == 0 ) {
+		lock_task(res_lock);
+		if ( _search_first_list_by_url(url_str,option) ) {
+			unlock_task(res_lock,"resource_check");
+			return CRS_LOADING;
+		}
+		unlock_task(res_lock,"resource_check");
 		if ( option != LRO_UNIT )
-			return -1;
+			return CRS_NOTHING;
 		if ( search_c_unit(url_str) )
-			return 0;
-		return -1;
+			return CRS_EXIST;
+		return CRS_NOTHING;
 	}
 	if ( r->h.initial_status == RS_ERROR )
-		return 0;
+		return CRS_ERROR;
 	if ( r->h.flags & RF_COMPLETE )
-		return 0;
-	return -1;
+		return CRS_EXIST;
+	return CRS_LOADING;
 }
 
 void
@@ -1726,18 +1767,52 @@ void
 free_resource_entry(RESOURCE * r)
 {
 	printf("free_Resource_entry\n");
+er_panic("free_resource_entry");
 	return;
 }
 
+int
+_check_lrw_status(LOAD_RESOURCE_WORK * w,int * sts,int len,
+	int flags,int mask)
+{
+int i;
+int ret;
+	ret = -1;
+	for ( i = 0 ; i < len ; i ++ ) {
+		if ( w->err == sts[i] )
+			ret = 0;
+	}
+	if ( ret < 0 )
+		return -1;
+	if ( w->result == 0 ) {
+		if ( flags == 0 && mask == 0 )
+			return 0;
+		return -1;
+	}
+	if ( (w->result->h.flags & mask) == flags )
+		return 0;
+	return -1;
+}
+
+int
+check_lrw_status(LOAD_RESOURCE_WORK * w,int * sts,int len,
+	int flags,int mask)
+{
+int ret;
+	lock_task(res_lock);
+	ret = _check_lrw_status(w,sts,len,flags,mask);
+	unlock_task(res_lock,"check_lrw_status");
+	return ret;
+}
+
+
 void
 _resource_cache_invoke(RESOURCE * r)
 {
 RS_BUF b;
 	b.r = r;
 	b.sexp = r->h.data;
-bomb();
 	set_rs_resource_cache(&b);
-bomb();
 
 	r->h.data = 0;
 }
@@ -1749,14 +1824,19 @@ resource_cache_invoke()
 int i;
 RESOURCE * r;
 extern RESOURCE ** res_no_hash_table;
+RESOURCE_TYPE_LIST * rt;
+int cnt,limit;
 
 printf("RESORCE CACHE INVOKE\n");
+	cnt = 0;
+	limit = 1;
 	for ( i = 0 ; i < RES_HASH_SIZE ; ) {
 		lock_task(res_lock);
 		for ( r = res_no_hash_table[i] ; r ; r = r->h.no_next )
 			if ( (r->h.flags & (RF_CACHE|RF_COMPLETE|RF_LOAD_EXTEND_PROC))
-					== RF_COMPLETE )
+					== RF_COMPLETE ) {
 				break;
+			}
 		if ( r == 0 ) {
 			unlock_task(res_lock,"resource_cache_invoke");
 			i ++;
@@ -1772,6 +1852,12 @@ printf("RESORCE CACHE INVOKE\n");
 		r->h.flags |= RF_CACHE;
 		wakeup_task((int)r);
 		unlock_task(res_lock,"resource_cache_invoke");
+		cnt ++;
+		if ( cnt >= limit ) {
+			sleep_sec(1);
+			cnt = 0;
+			limit = limit << 1;
+		}
 	}
 	flush_rs_cache();
 }
