@@ -564,6 +564,47 @@ XL_SEXP * sl;
 	gc_pop(0,0);
 }
 
+void
+write_native_proxy_server_list(STREAM * st,XL_SEXP * sl)
+{
+XL_SEXP * server_type;
+XL_SEXP * server_name;
+	server_type = get_el(sl,1);
+	server_name = get_el(sl,2);
+	s_printf(st,"<SetNativeProxy type=\"%ls\" direct=\"%ls\"/>\n",
+		server_type->string.data,
+		server_name->string.data);
+}
+
+void
+write_native_proxy_info(STREAM * st)
+{
+XL_SEXP * ret;
+XL_SEXP * type,* server, * port;
+XL_SEXP * sl;
+	gc_push(0,0,"write_proxy");
+	ret = get_native_proxyinfo();
+	type = get_el(ret,1);
+	if ( l_strcmp(type->string.data,
+			l_string(std_cm,"NoProxy")) == 0 ) {
+		return;
+	}
+	server = get_el(ret,2);
+	port = get_el(ret,3);
+
+	s_printf(st,"<SetNativeProxy type=\"%ls\" server=\"%ls\" port=\"%i\"/>\n",
+		type->string.data,
+		server->string.data,
+		port->integer.data);
+
+	sl = cdr(cdr(cdr(cdr(ret))));
+
+	for ( ; get_type(sl) == XLT_PAIR ; sl = cdr(sl) )
+		write_native_proxy_server_list(st,car(sl));
+
+	gc_pop(0,0);
+}
+
 void
 write_cache_info(STREAM * st)
 {
@@ -612,6 +653,7 @@ STREAM * st;
 	s_printf(st,"<gv-resource rid=\"4\">\n");
 
 	write_proxy_info(st);
+	write_native_proxy_info(st);
 	write_cache_info(st);
 
 	s_printf(st,"<initial-query type=\"direct\">\n");
