@@ -897,9 +897,9 @@ int ret_f;
 		lr = get_lr(0,lmp,0);
 
 		for ( lr1 = lr ; lr1 ; lr1 = lr1->next ) {
-/*
+
 ss_printf("retrieve loop %ls\n",lr1->lump_crd);
-*/
+
 			ret_f = 0;
 			lmp = load_meta(ses,"lump",lr1->lump_crd);
 			if ( get_type(lmp) == XLT_ERROR )
@@ -4151,29 +4151,35 @@ check_routing(SYS_QUEUE * q,T_RESOURCE_TO_INSERT * n,CR_WORK * w)
 int c;
 int ret;
 
+int sts1[2] = {
+	LRWE_HANDLING,
+	LRWE_DUP
+};
+int sts2[1] = {
+	LRWE_OK
+};
+#define STS_LEN	2
 
 	ret = 0;
 	if ( w->base_url == 0 ) {
 		ret = -1;
 		goto end;
 	}
-	if ( n->lr_crd->err == LRWE_HANDLING ) {
+	if ( check_lrw_status(n->lr_crd,sts1,STS_LEN,0,0) == 0 ) {
 		ret = -1;
 		goto end;
 	}
-	if ( n->lr_crd->err == LRWE_OK &&
-		(n->lr_crd->result->h.flags & RF_COMPLETE) == 0 ) {
+	if ( check_lrw_status(n->lr_crd,sts2,1,0,RF_COMPLETE) == 0 ) {
 		ret = -1;
 		goto end;
 	}
 	set_lrw_err(n->lr_crd,LRWE_COMPLETE);
 	if ( n->lr_obj ) {
-		if ( n->lr_obj->err == LRWE_HANDLING ) {
+		if ( check_lrw_status(n->lr_obj,sts1,STS_LEN,0,0) == 0 ) {
 			ret = -1;
 			goto end;
 		}
-		if ( n->lr_obj->err == LRWE_OK &&
-			(n->lr_obj->result->h.flags & RF_COMPLETE) == 0 ) {
+		if ( check_lrw_status(n->lr_obj,sts2,1,0,RF_COMPLETE) == 0 ) {
 			ret = -1;
 			goto end;
 		}
@@ -4186,18 +4192,20 @@ end:
 		break;
 	case 1:
 		c = check_mappath(w->base_url,n->crd_path,1);
-		n->mappath_loading = 2;
+		n->mappath_loading = 0;
 		w->loading_cnt --;
+/*
 	case 2:
 		c = check_mappath(w->base_url,n->crd_path,0);
 		if ( c == CRT_LOADING_RES )
 			c = CRT_LOADING_RES_RESOLVE;
 		else	n->mappath_loading = 0;
 		break;
-	}
-/*
-ss_printf("ret %i %i %ls : %x\n",ret,c,n->crd_path,w->flags[c]);
 */
+	}
+
+ss_printf("ret %i %i %ls : %x\n",ret,c,n->crd_path,w->flags[c]);
+
 	if ( ret == 0 ) {
 		w->count[c] ++;
 		if ( w->flags[c] )
@@ -4242,6 +4250,8 @@ XL_INTERPRETER * xli;
 int ses;
 CR_WORK cr;
 int ret;
+T_RESOURCE_TO_INSERT * last;
+int last_crt;
 
 	cr.base_url = 0;
 
@@ -4252,6 +4262,8 @@ int ret;
 	ses = open_session(SEST_OPTIMIZE);
 
 	cr.loading_cnt = 0;
+	last = 0;
+	last_crt = -1;
 	for ( ; ; ) {
 		gc_push(0,0,"beam_insert_task");
 		reset_cr_work(&cr);
@@ -4259,6 +4271,8 @@ int ret;
 			ret = check_queue(&rc.resource_to_insert,
 					check_routing,&cr);
 			if ( cr.count[CRT_EXIST] ) {
+				last = 0;
+				last_crt = -1;
 				cr.flags[CRT_EXIST] = 1;
 				n = delete_queue(&rc.resource_to_insert,
 					check_routing,&cr,0);
@@ -4266,10 +4280,10 @@ int ret;
 					goto loading;
 				goto ok;
 			}
-			if ( cr.count[CRT_LOADING_RES] ) {
-				if ( cr.loading_cnt > 2 )
+			if ( cr.count[CRT_ROUTING_EXIST] ) {
+				if ( cr.loading_cnt > 10 )
 					goto loading;
-				cr.flags[CRT_LOADING_RES] = 1;
+				cr.flags[CRT_ROUTING_EXIST] = 1;
 				n = delete_queue(&rc.resource_to_insert,
 					check_routing,&cr,0);
 				if ( n == 0 )
@@ -4277,7 +4291,14 @@ int ret;
 				n->mappath_loading = 1;
 				cr.loading_cnt ++;
 				insert_queue(&rc.resource_to_insert,n,1);
-				goto loading;
+				if ( last == n && last_crt == CRT_ROUTING_EXIST ) {
+					goto loading;
+				}
+				else {
+					last = n;
+					last_crt = CRT_ROUTING_EXIST;
+					goto imidiate;
+				}
 			}
 			if ( cr.count[CRT_NOTHING] ) {
 				cr.flags[CRT_NOTHING] = 1;
@@ -4290,12 +4311,21 @@ int ret;
 					n->crd_path,
 					RR_WM_NO_WAIT);
 				insert_queue(&rc.resource_to_insert,n,1);
-				goto loading;
+				if ( last == n && last_crt == CRT_NOTHING ) {
+					goto loading;
+				}
+				else {
+					last = n;
+					last_crt = CRT_NOTHING;
+					goto imidiate;
+				}
 			}
 			if ( cr.count[CRT_ERROR] ) {
 				cr.flags[CRT_ERROR] = 1;
 				n = delete_queue(&rc.resource_to_insert,
 					check_routing,&cr,1);
+				last = 0;
+				last_crt = -1;
 				goto err;
 			}
 			goto loading;
@@ -4326,8 +4356,6 @@ printf("insert_task del %i\n",get_tid());
 				unlock_task(radar_lock,
 					"beam_insert_task");
 			}
-if ( rc.base_url == 0 )
-er_panic("b");
 		}
 		unlock_base_url();
 
@@ -4359,6 +4387,9 @@ er_panic("b");
 	loading:
 		gc_pop(0,0);
 		sleep_sec(1);
+		continue;
+	imidiate:
+		gc_pop(0,0);
 	}
 }
 
