@@ -550,7 +550,7 @@ set_cpu_msg(304);
 set_cpu_msg(305);
 	}
 set_cpu_msg(306);
-	for ( ; get_type(par) ; par = cdr(par) ) {
+	for ( ; get_type(par) == XLT_PAIR ; par = cdr(par) ) {
 set_cpu_msg(307);
 		r = car(par);
 		if ( get_type(r) != XLT_PAIR )
