@@ -159,7 +159,7 @@ FREELIST * fp;
 	p = open_pdb(filename,oflags,mode,flags&PF_PDB_MASK);
 	if ( p == 0 )
 		return 0;
-	length = lseek(p->fid,0,SEEK_END);
+	length = u_lseek(p->fid,0,SEEK_END);
 	if ( length == 0 ) {
 		h.h.size = sizeof(h);
 		h.h.type = PNT_FILE_HEADER;
@@ -233,7 +233,7 @@ void
 load_freelist(PDB * p,PN_FREELIST * f,unsigned int fofs)
 {
 int er;
-	lseek(p->fid,fofs,SEEK_SET);
+	u_lseek(p->fid,fofs,SEEK_SET);
 	er = u_read(p->fid,f,sizeof(*f));
 	if ( er < sizeof(*f) )
 		er_panic("load_freelist");
@@ -247,7 +247,7 @@ int er;
 PN_FREELIST buf;
 	buf = *f;
 	change_endian_freelist_to_net(&buf);
-	lseek(p->fid,fofs,SEEK_SET);
+	u_lseek(p->fid,fofs,SEEK_SET);
 	er = fa_write(p->fid,&buf,sizeof(buf));
 	if ( er < sizeof(buf) )
 		er_panic("save_freelist");
@@ -408,7 +408,7 @@ FREELIST * fp,* fp1,* prev;
 unsigned int length;
 
 	load_freelist(p,&f,fofs);
-	length = lseek(p->fid,0,SEEK_END);
+	length = u_lseek(p->fid,0,SEEK_END);
 	if ( fofs + f.h.size >= length ) {
 		ftruncate(p->fid,fofs);
 		truncate_check(p,length);
@@ -500,7 +500,7 @@ unsigned int length;
 	if ( fp == 0 )
 		return -1;
 	header = fp->fofs;
-	length = lseek(p->fid,0,SEEK_END);
+	length = u_lseek(p->fid,0,SEEK_END);
 	prev = 0;
 	for ( ; fp ; prev = fp->fofs , fp = next_freelist(p,fp) ) {
 		if ( fp == 0 )
@@ -553,7 +553,7 @@ PN_HEADER h;
 char * str;
 unsigned int length;
 int er;
-	length = lseek(p->fid,0,SEEK_END);
+	length = u_lseek(p->fid,0,SEEK_END);
 	fofs = 0;
 	for ( ; ; ) {
 		if ( fofs == 0 )
@@ -562,7 +562,7 @@ int er;
 			str = "broken last segment";
 			goto err;
 		}
-		lseek(p->fid,fofs,SEEK_SET);
+		u_lseek(p->fid,fofs,SEEK_SET);
 		er = u_read(p->fid,&h,sizeof(h));
 		if ( er < sizeof(h) ) {
 			perror("cannot read");
@@ -594,7 +594,7 @@ unsigned short size;
 
 	h = d_alloc(sizeof(*h),1243);
 	h->a.fofs = fofs;
-	lseek(p->fid,fofs,SEEK_SET);
+	u_lseek(p->fid,fofs,SEEK_SET);
 	er = u_read(p->fid,&h->h,sizeof(h->h));
 	if ( er < sizeof(h->h) )
 		goto err;
@@ -619,7 +619,7 @@ unsigned short size;
 	a = h;
 	size = a->h.size;
 	change_endian_s(size);
-	lseek(p->fid,a->a.fofs,SEEK_SET);
+	u_lseek(p->fid,a->a.fofs,SEEK_SET);
 	return fa_write(p->fid,&a->h,size);
 }
 
