@@ -34,8 +34,8 @@ VERSION xl_proto_version = {
 	"XL.proto",
 	"XL",
 	"(C) 2000-2003 Hirohisa Mori",
-	"ver.A.02.09",
-	2002,9,19,
+	"ver.A.03",
+	2002,10,1,
 	0,
 	"XL protocol version"
 };
@@ -45,8 +45,8 @@ VERSION xl_code_version = {
 	"XL.code",
 	"XL",
 	"(C) 2000-2003 Hirohisa Mori",
-	"ver.A.02.10 (ASTROBOY)",
-	2003,9,19,
+	"ver.A.03.02 (ASTROBOY)",
+	2003,10,1,
 	0,
 	"version of XL code (src/xl)"
 };
