@@ -77,7 +77,7 @@ typedef struct con_server {
 
 #define LOCK_SET(s)	\
 	{(s)->lock_file = __FILE__;(s)->lock_line=__LINE__; \
-	(s)->lock_task = _get_tid();}
+	(s)->lock_task = get_tid();}
 
 typedef struct con_session {
 	struct con_session *	next;
@@ -452,8 +452,8 @@ _free_con_agent(CON_AGENT * a)
 {
 	_free_con_prefix(a->prefix);
 	d_f_ree(a->name);
-	d_f_ree(a);
 	_free_con_agent_initial(a->initial_list);
+	d_f_ree(a);
 }
 
 CON_SERVER *
@@ -1372,7 +1372,7 @@ retry:
 		ret = remote_query(a->iid,env,0,r);
 
 		if ( get_type(cdr(_cmd)) != XLT_PAIR &&
-				ret->h.type == XLT_DELAY ) {
+				ret && ret->h.type == XLT_DELAY ) {
 		XL_RESULT * resp;
 		int check_remote_session_delay();
 			lock_mem();
@@ -1543,9 +1543,9 @@ remote_session(
 	XLISP_ENV * env,
 	int id,
 	URL * u,
-	L_CHAR * a_agent,
-	L_CHAR * a_login_mode,
-	L_CHAR * a_center_cmd,
+	L_CHAR * _a_agent,
+	L_CHAR * _a_login_mode,
+	L_CHAR * _a_center_cmd,
 	XL_SEXP * cmd,
 	XL_FILE * f,
 	int ln,
@@ -1554,8 +1554,18 @@ remote_session(
 NPROXY_DIRECT_SERVER * is;
 XL_SEXP * send_query, * ret;
 char buf[20];
-	if ( native_proxy_session == 0 )
-		return _remote_session(
+L_CHAR * a_agent,* a_login_mode,* a_center_cmd;
+	if ( _a_agent )
+		a_agent = ll_copy_str(_a_agent,22);
+	else	a_agent = 0;
+	if ( _a_login_mode )
+		a_login_mode = ll_copy_str(_a_login_mode,22);
+	else	a_login_mode = 0;
+	if ( _a_center_cmd )
+		a_center_cmd = ll_copy_str(_a_center_cmd,21);
+	else	a_center_cmd = 0;
+	if ( native_proxy_session == 0 ) {
+		ret = _remote_session(
 				env,
 				id,
 				u,
@@ -1567,9 +1577,11 @@ char buf[20];
 				ln,
 				session_lock_enable,
 				0,0);
+		goto end;
+	}
 	is = search_direct_server(u->server);
-	if ( is )
-		return _remote_session(
+	if ( is ) {
+		ret = _remote_session(
 				env,
 				id,
 				u,
@@ -1581,26 +1593,28 @@ char buf[20];
 				ln,
 				session_lock_enable,
 				0,0);
-
+		goto end;
+	}
 
 	ret = setup_session_proxy(id,f,ln);
 	if ( get_type(ret) == XLT_ERROR )
-		return ret;
-	ret = _remote_session(
-			gblisp_top_env0,
-			native_proxy_session,
-			&native_proxy_url,
-			l_string(std_cm,"xlproxy"),
-			l_string(std_cm,"user"),
-			0,
-			ret,
-			f,
-			ln,
-			0,
-			0,
-			id);
+		goto end;
+	if ( get_type(ret) != XLT_NULL )
+		ret = _remote_session(
+				gblisp_top_env0,
+				native_proxy_session,
+				&native_proxy_url,
+				l_string(std_cm,"xlproxy"),
+				l_string(std_cm,"user"),
+				0,
+				ret,
+				f,
+				ln,
+				0,
+				0,
+				id);
 	if ( ret && ret->h.type == XLT_ERROR )
-		return ret;
+		goto end;
 
 	send_query = cmd;
 	if ( a_center_cmd )
@@ -1627,7 +1641,7 @@ char buf[20];
 		-1),
 		send_query);
 
-	sprintf(buf,"ps%i",id);
+	sprintf(buf,"rs%i",id);
 
 	send_query = cons(
 		n_get_symbol(buf),
@@ -1635,7 +1649,16 @@ char buf[20];
 	send_query = cons(
 		n_get_symbol("RemoteSession"),
 		send_query);
-	return _remote_session(
+/*
+ss_printf("SEND ");
+print_sexp(s_stdout,send_query,0);
+ss_printf("\n");
+ if ( a_center_cmd && l_strcmp(a_center_cmd,
+		l_string(std_cm,"://")) == 0 )
+er_panic("sopt");
+*/
+
+	ret = _remote_session(
 			env,
 			native_proxy_session,
 			&native_proxy_url,
@@ -1647,6 +1670,14 @@ char buf[20];
 			ln,
 			session_lock_enable,
 			0,id);
+end:
+	if ( a_agent )
+		d_f_ree(a_agent);
+	if ( a_login_mode )
+		d_f_ree(a_login_mode);
+	if ( a_center_cmd )
+		d_f_ree(a_center_cmd);
+	return ret;
 }
 
 
